package com.ruoyi.traceability.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.traceability.mapper.ProLogrecordMapper;
import com.ruoyi.traceability.domain.ProLogrecord;
import com.ruoyi.traceability.service.IProLogrecordService;
import com.ruoyi.common.core.text.Convert;

/**
 * 机台日志Service业务层处理
 * 
 * @author wenjy
 * @date 2022-12-01
 */
@Service
public class ProLogrecordServiceImpl implements IProLogrecordService 
{
    @Autowired
    private ProLogrecordMapper proLogrecordMapper;

    /**
     * 查询机台日志
     * 
     * @param id 机台日志主键
     * @return 机台日志
     */
    @Override
    public ProLogrecord selectProLogrecordById(Long id)
    {
        return proLogrecordMapper.selectProLogrecordById(id);
    }

    /**
     * 查询机台日志列表
     * 
     * @param proLogrecord 机台日志
     * @return 机台日志
     */
    @Override
    public List<ProLogrecord> selectProLogrecordList(ProLogrecord proLogrecord)
    {
        return proLogrecordMapper.selectProLogrecordList(proLogrecord);
    }

    /**
     * 新增机台日志
     * 
     * @param proLogrecord 机台日志
     * @return 结果
     */
    @Override
    public int insertProLogrecord(ProLogrecord proLogrecord)
    {
        return proLogrecordMapper.insertProLogrecord(proLogrecord);
    }

    /**
     * 修改机台日志
     * 
     * @param proLogrecord 机台日志
     * @return 结果
     */
    @Override
    public int updateProLogrecord(ProLogrecord proLogrecord)
    {
        return proLogrecordMapper.updateProLogrecord(proLogrecord);
    }

    /**
     * 批量删除机台日志
     * 
     * @param ids 需要删除的机台日志主键
     * @return 结果
     */
    @Override
    public int deleteProLogrecordByIds(String ids)
    {
        return proLogrecordMapper.deleteProLogrecordByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除机台日志信息
     * 
     * @param id 机台日志主键
     * @return 结果
     */
    @Override
    public int deleteProLogrecordById(Long id)
    {
        return proLogrecordMapper.deleteProLogrecordById(id);
    }
}
